/*******************************************************************************
 * University of Illinois/NCSA
 * Open Source License
 *
 * Copyright (c) 2010 , NCSA.  All rights reserved.
 *
 * Developed by:
 * Cyberenvironments and Technologies (CET)
 * http://cet.ncsa.illinois.edu/
 *
 * National Center for Supercomputing Applications (NCSA)
 * http://www.ncsa.illinois.edu/
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal with the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimers.
 * - Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimers in the
 *   documentation and/or other materials provided with the distribution.
 * - Neither the names of CET, University of Illinois/NCSA, nor the names
 *   of its contributors may be used to endorse or promote products
 *   derived from this Software without specific prior written permission.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE CONTRIBUTORS OR COPYRIGHT HOLDERS BE LIABLE FOR
 * ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
 * CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS WITH THE SOFTWARE.
 *******************************************************************************/
package edu.uiuc.ncsa.cet.bean.gis;

import java.io.Serializable;

import edu.uiuc.ncsa.cet.bean.BlobBean;
import edu.uiuc.ncsa.cet.bean.CETBean;
import edu.uiuc.ncsa.cet.bean.TagEventBean;

/**
 * GeoTag is composition of TagBean (through TagEvent) and
 * GeoSpatialGeometryBean. Basically to help represent some location on map with
 * string label consisting of tag and description. Better to use composition
 * than inheriting TagBean. Reason is each geometry location can have its own
 * description and blob associated whereas a tag is unique from perspective of
 * label attached to it. But a set of such geometry locations can be tagged with
 * same tag. E.g. "Searching locations of all earthquake epicenter stored in
 * database" using tag "Earthquake Epicenter".
 * 
 * @author kkotwani
 * 
 */
public class GeoTagBean extends CETBean implements Serializable {

	private static final long serialVersionUID = 5065037631597286658L;

	// Tag for tagging this Geo-Spatial location. To help find all the locations
	// tagged with particular tag
	private TagEventBean tagEvent = null;

	// Short description for this location. To help label it on map.
	private String description = "";

	// GeoSpatial geometry for locating on map. Can be Point, line or polygon on
	// geo space.
	private GeoSpatialGeometryBean geoSpatialGeometry = null;

	// A Blob can also be associated with a GeoTag or Tag.
	private BlobBean blob = null;

	public TagEventBean getTagEvent() {
		return tagEvent;
	}

	public void setTagEvent(TagEventBean tagEvent) {
		this.tagEvent = tagEvent;
	}

	public String getDescription() {
		return description;
	}

	public void setDescription(String description) {
		this.description = description;
	}

	public GeoSpatialGeometryBean getGeoSpatialGeometry() {
		return geoSpatialGeometry;
	}

	public void setGeoSpatialGeometry(GeoSpatialGeometryBean geoSpatialGeometry) {
		this.geoSpatialGeometry = geoSpatialGeometry;
	}

	public BlobBean getBlob() {
		return blob;
	}

	public void setBlob(BlobBean blob) {
		this.blob = blob;
	}
}
